==> haskell-colour-2.3.6-376-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-colour.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 colour
version:              2.3.6
visibility:           public
id:                   colour-2.3.6-2wv2ltb9NHWFgnG7RawbOn
key:                  colour-2.3.6-2wv2ltb9NHWFgnG7RawbOn
license:              MIT
maintainer:           Russell O'\''Connor <roconnor@theorem.ca>
author:               Russell O'\''Connor
homepage:             http://www.haskell.org/haskellwiki/Colour
synopsis:             A model for human colour/color perception
description:
    This package provides a data type for colours and transparency.
    Colours can be blended and composed.
    Various colour spaces are supported.
    A module of colour names ("Data.Colour.Names") is provided.

category:             data, graphics
abi:                  db83491144463ca9b2f7ad7ceb92d549
exposed:              True
exposed-modules:
    Data.Colour Data.Colour.CIE Data.Colour.CIE.Illuminant
    Data.Colour.Names Data.Colour.RGBSpace Data.Colour.RGBSpace.HSL
    Data.Colour.RGBSpace.HSV Data.Colour.SRGB Data.Colour.SRGB.Linear

hidden-modules:
    Data.Colour.Internal Data.Colour.Chan Data.Colour.RGB
    Data.Colour.Matrix Data.Colour.CIE.Chromaticity

import-dirs:          /usr/lib/ghc-9.4.8/site-local/colour-2.3.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/colour-2.3.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/colour-2.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-colour
hs-libraries:         HScolour-2.3.6-2wv2ltb9NHWFgnG7RawbOn
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-colour/html/colour.haddock
haddock-html:         /usr/share/doc/haskell-colour/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-colour-2.3.6-377-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-colour.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 colour
version:              2.3.6
visibility:           public
id:                   colour-2.3.6-5Hdg5NZuPkoIAWxSFkdA0e
key:                  colour-2.3.6-5Hdg5NZuPkoIAWxSFkdA0e
license:              MIT
maintainer:           Russell O'\''Connor <roconnor@theorem.ca>
author:               Russell O'\''Connor
homepage:             http://www.haskell.org/haskellwiki/Colour
synopsis:             A model for human colour/color perception
description:
    This package provides a data type for colours and transparency.
    Colours can be blended and composed.
    Various colour spaces are supported.
    A module of colour names ("Data.Colour.Names") is provided.

category:             data, graphics
abi:                  b659ba606d4b5d1ebb6d733eff337e43
exposed:              True
exposed-modules:
    Data.Colour Data.Colour.CIE Data.Colour.CIE.Illuminant
    Data.Colour.Names Data.Colour.RGBSpace Data.Colour.RGBSpace.HSL
    Data.Colour.RGBSpace.HSV Data.Colour.SRGB Data.Colour.SRGB.Linear

hidden-modules:
    Data.Colour.Internal Data.Colour.Chan Data.Colour.RGB
    Data.Colour.Matrix Data.Colour.CIE.Chromaticity

import-dirs:          /usr/lib/ghc-9.4.8/site-local/colour-2.3.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/colour-2.3.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/colour-2.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-colour
hs-libraries:         HScolour-2.3.6-5Hdg5NZuPkoIAWxSFkdA0e
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-colour/html/colour.haddock
haddock-html:         /usr/share/doc/haskell-colour/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
